@@ -42,6 +42,7 @@ from .type_defs import (
     CreateCustomLineItemOutputTypeDef,
     CreatePricingPlanOutputTypeDef,
     CreatePricingRuleOutputTypeDef,
+    CreateTieringInputTypeDef,
     CustomLineItemBillingPeriodRangeTypeDef,
     CustomLineItemChargeDetailsTypeDef,
     DeleteBillingGroupOutputTypeDef,
@@ -74,6 +75,7 @@ from .type_defs import (
     UpdateCustomLineItemOutputTypeDef,
     UpdatePricingPlanOutputTypeDef,
     UpdatePricingRuleOutputTypeDef,
+    UpdateTieringInputTypeDef,
 )
 
 if sys.version_info >= (3, 9):
@@ -248,12 +250,13 @@ class BillingConductorClient(BaseClient):
         Name: str,
         Scope: PricingRuleScopeType,
         Type: PricingRuleTypeType,
-        ModifierPercentage: float,
         ClientToken: str = ...,
         Description: str = ...,
+        ModifierPercentage: float = ...,
         Service: str = ...,
         Tags: Mapping[str, str] = ...,
-        BillingEntity: str = ...
+        BillingEntity: str = ...,
+        Tiering: CreateTieringInputTypeDef = ...
     ) -> CreatePricingRuleOutputTypeDef:
         """
         Creates a pricing rule can be associated to a pricing plan, or a set of pricing
@@ -562,7 +565,8 @@ class BillingConductorClient(BaseClient):
         Name: str = ...,
         Description: str = ...,
         Type: PricingRuleTypeType = ...,
-        ModifierPercentage: float = ...
+        ModifierPercentage: float = ...,
+        Tiering: UpdateTieringInputTypeDef = ...
     ) -> UpdatePricingRuleOutputTypeDef:
         """
         Updates an existing pricing rule.
