@@ -40,8 +40,8 @@ __all__ = (
     "CustomLineItemBillingPeriodRangeTypeDef",
     "BillingGroupCostReportElementTypeDef",
     "ComputationPreferenceTypeDef",
+    "CreateFreeTierConfigTypeDef",
     "CreatePricingPlanInputRequestTypeDef",
-    "CreatePricingRuleInputRequestTypeDef",
     "CustomLineItemFlatChargeDetailsTypeDef",
     "CustomLineItemPercentageChargeDetailsTypeDef",
     "DeleteBillingGroupInputRequestTypeDef",
@@ -49,6 +49,7 @@ __all__ = (
     "DeletePricingRuleInputRequestTypeDef",
     "DisassociateAccountsInputRequestTypeDef",
     "DisassociatePricingRulesInputRequestTypeDef",
+    "FreeTierConfigTypeDef",
     "ListAccountAssociationsFilterTypeDef",
     "PaginatorConfigTypeDef",
     "ListBillingGroupCostReportsFilterTypeDef",
@@ -62,7 +63,6 @@ __all__ = (
     "PricingPlanListElementTypeDef",
     "ListPricingRulesAssociatedToPricingPlanInputRequestTypeDef",
     "ListPricingRulesFilterTypeDef",
-    "PricingRuleListElementTypeDef",
     "ListResourcesAssociatedToCustomLineItemFilterTypeDef",
     "ListResourcesAssociatedToCustomLineItemResponseElementTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
@@ -70,8 +70,8 @@ __all__ = (
     "UntagResourceRequestRequestTypeDef",
     "UpdateCustomLineItemFlatChargeDetailsTypeDef",
     "UpdateCustomLineItemPercentageChargeDetailsTypeDef",
+    "UpdateFreeTierConfigTypeDef",
     "UpdatePricingPlanInputRequestTypeDef",
-    "UpdatePricingRuleInputRequestTypeDef",
     "AssociateAccountsOutputTypeDef",
     "AssociatePricingRulesOutputTypeDef",
     "CreateBillingGroupOutputTypeDef",
@@ -90,7 +90,6 @@ __all__ = (
     "ListTagsForResourceResponseTypeDef",
     "UpdateBillingGroupOutputTypeDef",
     "UpdatePricingPlanOutputTypeDef",
-    "UpdatePricingRuleOutputTypeDef",
     "AssociateResourceResponseElementTypeDef",
     "DisassociateResourceResponseElementTypeDef",
     "BatchAssociateResourcesToCustomLineItemInputRequestTypeDef",
@@ -100,7 +99,9 @@ __all__ = (
     "BillingGroupListElementTypeDef",
     "CreateBillingGroupInputRequestTypeDef",
     "UpdateBillingGroupInputRequestTypeDef",
+    "CreateTieringInputTypeDef",
     "CustomLineItemChargeDetailsTypeDef",
+    "TieringTypeDef",
     "ListAccountAssociationsInputRequestTypeDef",
     "ListAccountAssociationsInputListAccountAssociationsPaginateTypeDef",
     "ListPricingPlansAssociatedWithPricingRuleInputListPricingPlansAssociatedWithPricingRulePaginateTypeDef",
@@ -118,21 +119,26 @@ __all__ = (
     "ListPricingPlansOutputTypeDef",
     "ListPricingRulesInputListPricingRulesPaginateTypeDef",
     "ListPricingRulesInputRequestTypeDef",
-    "ListPricingRulesOutputTypeDef",
     "ListResourcesAssociatedToCustomLineItemInputListResourcesAssociatedToCustomLineItemPaginateTypeDef",
     "ListResourcesAssociatedToCustomLineItemInputRequestTypeDef",
     "ListResourcesAssociatedToCustomLineItemOutputTypeDef",
     "UpdateCustomLineItemChargeDetailsTypeDef",
+    "UpdateTieringInputTypeDef",
     "BatchAssociateResourcesToCustomLineItemOutputTypeDef",
     "BatchDisassociateResourcesFromCustomLineItemOutputTypeDef",
     "ListBillingGroupsOutputTypeDef",
+    "CreatePricingRuleInputRequestTypeDef",
     "CreateCustomLineItemInputRequestTypeDef",
+    "PricingRuleListElementTypeDef",
     "CustomLineItemListElementTypeDef",
     "CustomLineItemVersionListElementTypeDef",
     "UpdateCustomLineItemOutputTypeDef",
     "ListCustomLineItemVersionsInputListCustomLineItemVersionsPaginateTypeDef",
     "ListCustomLineItemVersionsInputRequestTypeDef",
     "UpdateCustomLineItemInputRequestTypeDef",
+    "UpdatePricingRuleInputRequestTypeDef",
+    "UpdatePricingRuleOutputTypeDef",
+    "ListPricingRulesOutputTypeDef",
     "ListCustomLineItemsOutputTypeDef",
     "ListCustomLineItemVersionsOutputTypeDef",
 )
@@ -233,6 +239,13 @@ ComputationPreferenceTypeDef = TypedDict(
     },
 )
 
+CreateFreeTierConfigTypeDef = TypedDict(
+    "CreateFreeTierConfigTypeDef",
+    {
+        "Activated": bool,
+    },
+)
+
 _RequiredCreatePricingPlanInputRequestTypeDef = TypedDict(
     "_RequiredCreatePricingPlanInputRequestTypeDef",
     {
@@ -257,34 +270,6 @@ class CreatePricingPlanInputRequestTypeDef(
     pass
 
 
-_RequiredCreatePricingRuleInputRequestTypeDef = TypedDict(
-    "_RequiredCreatePricingRuleInputRequestTypeDef",
-    {
-        "Name": str,
-        "Scope": PricingRuleScopeType,
-        "Type": PricingRuleTypeType,
-        "ModifierPercentage": float,
-    },
-)
-_OptionalCreatePricingRuleInputRequestTypeDef = TypedDict(
-    "_OptionalCreatePricingRuleInputRequestTypeDef",
-    {
-        "ClientToken": str,
-        "Description": str,
-        "Service": str,
-        "Tags": Mapping[str, str],
-        "BillingEntity": str,
-    },
-    total=False,
-)
-
-
-class CreatePricingRuleInputRequestTypeDef(
-    _RequiredCreatePricingRuleInputRequestTypeDef, _OptionalCreatePricingRuleInputRequestTypeDef
-):
-    pass
-
-
 CustomLineItemFlatChargeDetailsTypeDef = TypedDict(
     "CustomLineItemFlatChargeDetailsTypeDef",
     {
@@ -351,6 +336,13 @@ DisassociatePricingRulesInputRequestTypeDef = TypedDict(
     },
 )
 
+FreeTierConfigTypeDef = TypedDict(
+    "FreeTierConfigTypeDef",
+    {
+        "Activated": bool,
+    },
+)
+
 ListAccountAssociationsFilterTypeDef = TypedDict(
     "ListAccountAssociationsFilterTypeDef",
     {
@@ -497,24 +489,6 @@ ListPricingRulesFilterTypeDef = TypedDict(
     total=False,
 )
 
-PricingRuleListElementTypeDef = TypedDict(
-    "PricingRuleListElementTypeDef",
-    {
-        "Name": str,
-        "Arn": str,
-        "Description": str,
-        "Scope": PricingRuleScopeType,
-        "Type": PricingRuleTypeType,
-        "ModifierPercentage": float,
-        "Service": str,
-        "AssociatedPricingPlanCount": int,
-        "CreationTime": int,
-        "LastModifiedTime": int,
-        "BillingEntity": str,
-    },
-    total=False,
-)
-
 ListResourcesAssociatedToCustomLineItemFilterTypeDef = TypedDict(
     "ListResourcesAssociatedToCustomLineItemFilterTypeDef",
     {
@@ -570,6 +544,13 @@ UpdateCustomLineItemPercentageChargeDetailsTypeDef = TypedDict(
     },
 )
 
+UpdateFreeTierConfigTypeDef = TypedDict(
+    "UpdateFreeTierConfigTypeDef",
+    {
+        "Activated": bool,
+    },
+)
+
 _RequiredUpdatePricingPlanInputRequestTypeDef = TypedDict(
     "_RequiredUpdatePricingPlanInputRequestTypeDef",
     {
@@ -592,30 +573,6 @@ class UpdatePricingPlanInputRequestTypeDef(
     pass
 
 
-_RequiredUpdatePricingRuleInputRequestTypeDef = TypedDict(
-    "_RequiredUpdatePricingRuleInputRequestTypeDef",
-    {
-        "Arn": str,
-    },
-)
-_OptionalUpdatePricingRuleInputRequestTypeDef = TypedDict(
-    "_OptionalUpdatePricingRuleInputRequestTypeDef",
-    {
-        "Name": str,
-        "Description": str,
-        "Type": PricingRuleTypeType,
-        "ModifierPercentage": float,
-    },
-    total=False,
-)
-
-
-class UpdatePricingRuleInputRequestTypeDef(
-    _RequiredUpdatePricingRuleInputRequestTypeDef, _OptionalUpdatePricingRuleInputRequestTypeDef
-):
-    pass
-
-
 AssociateAccountsOutputTypeDef = TypedDict(
     "AssociateAccountsOutputTypeDef",
     {
@@ -779,23 +736,6 @@ UpdatePricingPlanOutputTypeDef = TypedDict(
     },
 )
 
-UpdatePricingRuleOutputTypeDef = TypedDict(
-    "UpdatePricingRuleOutputTypeDef",
-    {
-        "Arn": str,
-        "Name": str,
-        "Description": str,
-        "Scope": PricingRuleScopeType,
-        "Type": PricingRuleTypeType,
-        "ModifierPercentage": float,
-        "Service": str,
-        "AssociatedPricingPlanCount": int,
-        "LastModifiedTime": int,
-        "BillingEntity": str,
-        "ResponseMetadata": ResponseMetadataTypeDef,
-    },
-)
-
 AssociateResourceResponseElementTypeDef = TypedDict(
     "AssociateResourceResponseElementTypeDef",
     {
@@ -958,6 +898,13 @@ class UpdateBillingGroupInputRequestTypeDef(
     pass
 
 
+CreateTieringInputTypeDef = TypedDict(
+    "CreateTieringInputTypeDef",
+    {
+        "FreeTier": CreateFreeTierConfigTypeDef,
+    },
+)
+
 _RequiredCustomLineItemChargeDetailsTypeDef = TypedDict(
     "_RequiredCustomLineItemChargeDetailsTypeDef",
     {
@@ -980,6 +927,13 @@ class CustomLineItemChargeDetailsTypeDef(
     pass
 
 
+TieringTypeDef = TypedDict(
+    "TieringTypeDef",
+    {
+        "FreeTier": FreeTierConfigTypeDef,
+    },
+)
+
 ListAccountAssociationsInputRequestTypeDef = TypedDict(
     "ListAccountAssociationsInputRequestTypeDef",
     {
@@ -1191,16 +1145,6 @@ ListPricingRulesInputRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListPricingRulesOutputTypeDef = TypedDict(
-    "ListPricingRulesOutputTypeDef",
-    {
-        "BillingPeriod": str,
-        "PricingRules": List[PricingRuleListElementTypeDef],
-        "NextToken": str,
-        "ResponseMetadata": ResponseMetadataTypeDef,
-    },
-)
-
 _RequiredListResourcesAssociatedToCustomLineItemInputListResourcesAssociatedToCustomLineItemPaginateTypeDef = TypedDict(
     "_RequiredListResourcesAssociatedToCustomLineItemInputListResourcesAssociatedToCustomLineItemPaginateTypeDef",
     {
@@ -1269,6 +1213,13 @@ UpdateCustomLineItemChargeDetailsTypeDef = TypedDict(
     total=False,
 )
 
+UpdateTieringInputTypeDef = TypedDict(
+    "UpdateTieringInputTypeDef",
+    {
+        "FreeTier": UpdateFreeTierConfigTypeDef,
+    },
+)
+
 BatchAssociateResourcesToCustomLineItemOutputTypeDef = TypedDict(
     "BatchAssociateResourcesToCustomLineItemOutputTypeDef",
     {
@@ -1296,6 +1247,35 @@ ListBillingGroupsOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredCreatePricingRuleInputRequestTypeDef = TypedDict(
+    "_RequiredCreatePricingRuleInputRequestTypeDef",
+    {
+        "Name": str,
+        "Scope": PricingRuleScopeType,
+        "Type": PricingRuleTypeType,
+    },
+)
+_OptionalCreatePricingRuleInputRequestTypeDef = TypedDict(
+    "_OptionalCreatePricingRuleInputRequestTypeDef",
+    {
+        "ClientToken": str,
+        "Description": str,
+        "ModifierPercentage": float,
+        "Service": str,
+        "Tags": Mapping[str, str],
+        "BillingEntity": str,
+        "Tiering": CreateTieringInputTypeDef,
+    },
+    total=False,
+)
+
+
+class CreatePricingRuleInputRequestTypeDef(
+    _RequiredCreatePricingRuleInputRequestTypeDef, _OptionalCreatePricingRuleInputRequestTypeDef
+):
+    pass
+
+
 _RequiredCreateCustomLineItemInputRequestTypeDef = TypedDict(
     "_RequiredCreateCustomLineItemInputRequestTypeDef",
     {
@@ -1323,6 +1303,25 @@ class CreateCustomLineItemInputRequestTypeDef(
     pass
 
 
+PricingRuleListElementTypeDef = TypedDict(
+    "PricingRuleListElementTypeDef",
+    {
+        "Name": str,
+        "Arn": str,
+        "Description": str,
+        "Scope": PricingRuleScopeType,
+        "Type": PricingRuleTypeType,
+        "ModifierPercentage": float,
+        "Service": str,
+        "AssociatedPricingPlanCount": int,
+        "CreationTime": int,
+        "LastModifiedTime": int,
+        "BillingEntity": str,
+        "Tiering": TieringTypeDef,
+    },
+    total=False,
+)
+
 CustomLineItemListElementTypeDef = TypedDict(
     "CustomLineItemListElementTypeDef",
     {
@@ -1444,6 +1443,59 @@ class UpdateCustomLineItemInputRequestTypeDef(
     pass
 
 
+_RequiredUpdatePricingRuleInputRequestTypeDef = TypedDict(
+    "_RequiredUpdatePricingRuleInputRequestTypeDef",
+    {
+        "Arn": str,
+    },
+)
+_OptionalUpdatePricingRuleInputRequestTypeDef = TypedDict(
+    "_OptionalUpdatePricingRuleInputRequestTypeDef",
+    {
+        "Name": str,
+        "Description": str,
+        "Type": PricingRuleTypeType,
+        "ModifierPercentage": float,
+        "Tiering": UpdateTieringInputTypeDef,
+    },
+    total=False,
+)
+
+
+class UpdatePricingRuleInputRequestTypeDef(
+    _RequiredUpdatePricingRuleInputRequestTypeDef, _OptionalUpdatePricingRuleInputRequestTypeDef
+):
+    pass
+
+
+UpdatePricingRuleOutputTypeDef = TypedDict(
+    "UpdatePricingRuleOutputTypeDef",
+    {
+        "Arn": str,
+        "Name": str,
+        "Description": str,
+        "Scope": PricingRuleScopeType,
+        "Type": PricingRuleTypeType,
+        "ModifierPercentage": float,
+        "Service": str,
+        "AssociatedPricingPlanCount": int,
+        "LastModifiedTime": int,
+        "BillingEntity": str,
+        "Tiering": UpdateTieringInputTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListPricingRulesOutputTypeDef = TypedDict(
+    "ListPricingRulesOutputTypeDef",
+    {
+        "BillingPeriod": str,
+        "PricingRules": List[PricingRuleListElementTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 ListCustomLineItemsOutputTypeDef = TypedDict(
     "ListCustomLineItemsOutputTypeDef",
     {
